@@ -10,3 +10,8 @@ Gets emitted when the orientation changes to portrait.
 @since: 2009.09
 """
 
+def ASR_ACT_FORCE_LANDSCAPE(value): pass
+"""
+Forces landscape mode.
+@since: 2009.11.22
+"""
