@@ -186,11 +186,11 @@ def MEDIA_ACT_NEXT(): pass
 Instructs the current media player to skip to the next item.
 """
 
-def MEDIA_EV_LOADED(viewer, f): pass
+def MEDIA_EV_LOADED(player, f): pass
 """
 Gets emitted when a media player has loaded a file.
 
-@param viewer: the viewer that has loaded the file
+@param player: the player that has loaded the file
 @param f: file object
 """
 
@@ -254,7 +254,38 @@ given in seconds.
 """
 
 
+def MEDIA_EV_OUTPUT_ADDED(output): pass
+"""
+Gets emitted when a new output device is added.
+@since: 2009.11.01
 
+@param output: a MediaOutput object
+"""
+
+def MEDIA_EV_OUTPUT_REMOVED(output): pass
+"""
+Gets emitted when output device is removed.
+@since: 2009.11.01
+
+@param output: a MediaOutput object
+"""
+
+def MEDIA_ACT_SELECT_OUTPUT(output): pass
+"""
+Selects the given media output. Pass C{None} for the output to let the
+user choose.
+@since: 2009.10.31
+
+@param output: a MediaOutput object or C{None}
+"""
+
+def MEDIA_SVC_GET_OUTPUT(): pass
+"""
+Returns the currently selected media output.
+@since: 2009.10.31
+
+@return: a MediaOutput object
+"""
 
 
 def BOOKMARK_SVC_LIST(mimetypes): pass
@@ -290,6 +321,25 @@ Gets emitted when the list of bookmarks changes.
 """
 
 
+def THUMBNAIL_SVC_LOOKUP_THUMBNAIL(f): pass
+"""
+Looks up a thumbnail for the given file.
+
+@param f: file object
+@return: path of thumbnail file and whether the thumbnail is final
+"""
+
+def THUMBNAIL_SVC_LOAD_THUMBNAIL(f, cb, *args): pass
+"""
+Loads a thumbnail for the given file asynchronously, invoking the given callback
+when a thumbnail has been found or was created.
+
+@param f: file object
+@param cb: callback handler
+@param args: variable list of arguments to the callback handler
+"""
+
+
 def UI_ACT_FREEZE(): pass
 """
 Freezes UI updates globally. No parts of the UI are redrawn during a freeze.
@@ -325,11 +375,20 @@ it for, e.g., providing talk navigation.
 @param text_to_say: text string
 """
 
+def UI_ACT_SHOW_INFO(text): pass
+"""
+Displays an info notification.
+@since: 2009.12.22
+
+@param text: text to display
+"""
+
 def UI_ACT_SHOW_MESSAGE(text, subtext, icon): pass
 """
 Displays an overlay message. The message is displayed until
 L{UI_ACT_HIDE_MESSAGE} is called.
 
+
 @param text: title text
 @param subtext: message text
 @param icon: pixbuf object or C{None}
@@ -354,6 +413,14 @@ Gets emitted when a storage device has been selected.
 @param device_id: device ID string
 """
 
+def UI_ACT_SHOW_DIALOG(name): pass
+"""
+Shows the dialog window given by its name.
+@since: 2009.11.17
+
+@param name: name of the dialog window
+"""
+
 def UI_ACT_SELECT_VIEW(name): pass
 """
 Selects a view by name.
