@@ -10,6 +10,9 @@ _PBUF = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, True, 8, 160, 120)
 
 
 class ImageThumbnailer(Thumbnailer):
+    """
+    Thumbnailer for image media.
+    """
 
     def __init__(self):
     
@@ -28,14 +31,26 @@ class ImageThumbnailer(Thumbnailer):
         if (thumb):
             return (thumb, True)
         elif (f.mimetype == "application/x-image-folder"):
-            return (theme.mb_thumbnail_image_folder.get_path(), True)
+            return (theme.mb_folder_image_album.get_path(), False)
         else:
-            return (theme.mb_frame_image.get_path(), False)
+            return (theme.mb_file_image.get_path(), False)
         
         
     def make_thumbnail(self, f, cb, *args):
+
+        def on_loaded_folder(pbuf):
+            if (pbuf):
+                _PBUF.fill(0x00000000)
+                pixbuftools.draw_pbuf(_PBUF, theme.mb_frame_image_album, 0, 0)
+                # TODO: the frame coords should really be supplied by the theme
+                pixbuftools.fit_pbuf(_PBUF, pbuf, 49, 38, 79, 42)
+                path = self._set_thumbnail(f, _PBUF)
+                del pbuf
+            else:
+                path = ""
+            cb(path, *args)
     
-        def on_loaded(pbuf):
+        def on_loaded_image(pbuf):
             if (pbuf):
                 _PBUF.fill(0x00000000)
                 pixbuftools.draw_pbuf(_PBUF, theme.mb_frame_image, 0, 0)
@@ -46,6 +61,16 @@ class ImageThumbnailer(Thumbnailer):
                 path = ""
             cb(path, *args)
 
-        uri = f.resource
-        imageloader.load(uri, on_loaded)
+        if (f.mimetype == "application/x-image-folder"):
+            children = f.get_children()
+            if (children):
+                uri = children[0].resource
+                imageloader.load(uri, on_loaded_folder)
+            else:
+                cb("", *args)
+
+        else:
+            uri = f.resource
+            imageloader.load(uri, on_loaded_image)
+
 
