@@ -2,8 +2,6 @@ from com import msgs
 from storage import Device, File
 from ui.dialog import OptionDialog
 from utils import mimetypes
-from utils import maemo
-from utils import mmc
 from utils import logging
 from theme import theme
 
@@ -12,16 +10,33 @@ import commands
 import gobject
 
 
+# some beautifications of places (table: path -> (name, info, icon))
+_BEAUTIFUL_PLACES = {
+    "/media/mmc1": ("SD card", "", theme.mb_folder_microsd),
+    "/home/user/MyDocs": ("My Documents", "", theme.mb_folder_mydocs),
+    "/media/mmc1/DCIM": ("Camera Folder", "", theme.mb_folder_dcim),
+    "/home/user/MyDocs/DCIM": ("Camera Folder", "", theme.mb_folder_dcim),
+    "/home/user/MyDocs/.sounds": ("Audio Clips", "", theme.mb_folder_audioclips),
+    "/home/user/MyDocs/.videos": ("Video Clips", "", theme.mb_folder_videoclips),
+    "/home/user/MyDocs/.images": ("Pictures", "", theme.mb_folder_imageclips),
+}
+
+
+_DOTTED_WHITELIST = [".sounds", ".videos", ".images"]
+
 
 class LocalDevice(Device):
+    """
+    Storage device for browsing the local filesystem.
+    """
 
-    CATEGORY = Device.CATEGORY_CORE
+    CATEGORY = Device.CATEGORY_LOCAL
     TYPE = Device.TYPE_GENERIC
     
 
     def __init__(self):
     
-        self.__name = commands.getoutput("hostname")
+        self.__name = "Filesystem" #commands.getoutput("hostname")
         Device.__init__(self)
         
         
@@ -48,91 +63,29 @@ class LocalDevice(Device):
 
     def get_icon(self):
     
-        return theme.mb_device_nit
+        return theme.mb_folder_device
 
 
     def get_root(self):
     
         f = File(self)
         f.is_local = True
-        f.path = "MENU"
+        f.path = "/"
         f.mimetype = f.DEVICE_ROOT
         f.resource = ""
         f.name = self.__name
         f.info = "Browse the filesystem"
         f.icon = self.get_icon().get_path()
-        f.folder_flags = f.ITEMS_ENQUEUEABLE
+        f.folder_flags = f.ITEMS_ENQUEUEABLE # | f.ITEMS_COMPACT
 
         return f
-        
-        
-    def __ls_menu(self, cb, *args):
     
-        for name, path, mimetype, emblem in \
-          [("Memory Cards", "MMC", File.DIRECTORY, None),
-           ("Audio Clips", "/home/user/MyDocs/.sounds", File.DIRECTORY, theme.mb_filetype_audio),
-           ("Video Clips", "/home/user/MyDocs/.videos", File.DIRECTORY, theme.mb_filetype_video),
-           ("Images", "/home/user/MyDocs/.images", File.DIRECTORY, theme.mb_filetype_image),
-           ("Documents", maemo.IS_MAEMO and "/home/user/MyDocs/.documents"
-                                        or os.path.expanduser("~"),
-                                        File.DIRECTORY, None),
-           ("System", "/", File.DIRECTORY, None)]:
-            item = File(self)
-            item.is_local = True
-            item.can_add_to_library = True
-            item.path = path
-            item.resource = path
-            #item.child_count = self.__get_child_count(path)
-            item.name = name
-            item.acoustic_name = item.name
-            item.mimetype = mimetype
-            item.folder_flags = item.ITEMS_ENQUEUEABLE | \
-                                item.INDEXABLE
-
-            cb(item, *args)
-        #end for
-        
-        cb(None, *args)
-                
-        
-    def __ls_mmcs(self, cb, *args):
-    
-        for f in [ f for f in os.listdir("/media")
-                   if os.path.isdir(os.path.join("/media", f)) ]:
-            path = os.path.join("/media", f)
-            item = File(self)
-            item.is_local = True
-            item.path = path
-            item.resource = path
-            item.mtime = os.path.getmtime(path)
-            #item.child_count = self.__get_child_count(path)            
-            item.name = mmc.get_label(path)
-            item.acoustic_name = item.name + ", Volume"
-            item.mimetype = File.DIRECTORY
-            item.folder_flags = item.ITEMS_ENQUEUEABLE | \
-                                item.INDEXABLE
-
-            cb(item, *args)
-        #end for
-        
-        cb(None, *args)        
-
 
     def __on_add_to_playlist(self, folder, f):
     
         self.emit_message(msgs.PLAYLIST_ACT_APPEND, "", f)
 
 
-    def __on_put_on_dashboard(self, folder, f):
-        
-        f.bookmarked = True
-
-
-    def __on_add_to_library(self, folder, f):
-    
-        self.emit_message(msgs,LIBRARY_ACT_ADD_MEDIAROOT, f)
-
-
     def __on_delete_file(self, folder, f):
     
         dlg = OptionDialog("Really delete this file?")
@@ -144,6 +97,7 @@ class LocalDevice(Device):
             if (choice == 0):
                 try:
                     os.unlink(f.resource)
+                    self.emit_message(msgs.FILEINDEX_SVC_REMOVE, f.resource)
                 except:
                     pass
                 self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, folder)
@@ -151,13 +105,17 @@ class LocalDevice(Device):
         #end if
 
 
+    def __on_add_to_file_index(self, folder, f):
+    
+        self.emit_message(msgs.FILEINDEX_ACT_SCAN_FOLDER, f.resource)
+
+
     def get_file_actions(self, folder, f):
     
-        actions = []
-        actions.append((None, "Add to Playlist", self.__on_add_to_playlist))
-        actions.append((None, "Put on Dashboard", self.__on_put_on_dashboard))
+        actions = Device.get_file_actions(self, folder, f)
+
         if (f.mimetype == f.DIRECTORY):
-            actions.append((None, "Add to Library", self.__on_add_to_library))
+            actions.append((None, "Scan for Media", self.__on_add_to_file_index))
         else:
             actions.append((None, "Delete File", self.__on_delete_file))
         
@@ -176,14 +134,6 @@ class LocalDevice(Device):
         if (os.path.isdir(item.resource)):
             item.acoustic_name = item.name + ", Folder"
             item.mimetype = item.DIRECTORY
-            #children = item.get_children()
-            #for c in children:
-            #    if (c.mimetype.startswith("audio/")
-            #        and c.mimetype != "application/x-music-folder"):
-            #        item.mimetype = "application/x-music-folder"
-            #        break
-            ##end for
-            #item.child_count = len(children)
             item.folder_flags = item.ITEMS_ENQUEUEABLE | \
                                 item.INDEXABLE | \
                                 item.ITEMS_SKIPPABLE
@@ -192,14 +142,19 @@ class LocalDevice(Device):
             item.acoustic_name = os.path.splitext(item.name)[0]
             ext = os.path.splitext(path)[-1].lower()
             item.mimetype = mimetypes.lookup_ext(ext)
-            item.info = mimetypes.mimetype_to_name(item.mimetype)
+            item.info = mimetypes.mimetype_to_name(item.mimetype) + " file"
+        
+        if (item.resource in _BEAUTIFUL_PLACES):
+            name, info, icon = _BEAUTIFUL_PLACES[item.resource]
+            item.name = name
+            item.info = info
+            item.icon = icon.get_path()
         
         return item
     
-        
-        
-    def ls_async(self, path, cb, *args):
-                   
+    
+    def get_contents(self, folder, begin_at, end_at, cb, *args):
+
         def comp(a, b):
             if (a.mimetype != b.mimetype):
                 if (a.mimetype == a.DIRECTORY):
@@ -210,43 +165,20 @@ class LocalDevice(Device):
                     return cmp(a.name.lower(), b.name.lower())
             else:
                 return cmp(a.name.lower(), b.name.lower())
-                
-                   
-        if (path == "MENU"):
-            return self.__ls_menu(cb, *args)
-            
-        elif (path == "MMC"):
-            return self.__ls_mmcs(cb, *args)
-    
-        #logging.debug("listing [%s]" % path)
+
+
         try:
-            files = [ f for f in os.listdir(path)
-                      if not f.startswith(".") ]
+            files = [ f for f in os.listdir(folder.path)
+                      if not f.startswith(".") or f in _DOTTED_WHITELIST ]
         except:
             files = []
-        files.sort()
             
         items = []
         for f in files:
             try:
-                item = self.get_file(os.path.join(path, f))
+                item = self.get_file(os.path.join(folder.path, f))
             except:
                 continue
-            #item = File(self)
-            #item.is_local = True
-            #item.can_add_to_library = True
-            #item.path = os.path.join(path, f)
-            #item.name = f
-            #item.parent = os.path.basename(path)
-            #item.resource = os.path.join(path, f)
-
-            #if (os.path.isdir(item.resource)):
-            #    item.mimetype = item.DIRECTORY
-            #    item.child_count = self.__get_child_count(item.path)
-            #else:
-            #    ext = os.path.splitext(f)[-1].lower()
-            #    item.mimetype = mimetypes.lookup_ext(ext)
-            #    #item.emblem = theme.filetype_image
 
             if (item.mimetype.startswith("audio/") or
                 item.mimetype.startswith("image/") or
@@ -257,8 +189,13 @@ class LocalDevice(Device):
         
         items.sort(comp)
         
-        for i in items:
-            cb(i, *args)
+        cnt = -1
+        for item in items:
+            cnt += 1
+            if (cnt < begin_at): continue
+            if (end_at and cnt > end_at): break
+            cb(item, *args)
+        #end for
         cb(None, *args)
         
         
