@@ -13,8 +13,11 @@ def get_devices():
     #from BookmarkDevice import VideoBookmarkDevice
     #from BookmarkDevice import ImageBookmarkDevice
     
-    devices = [AudioStorage, AudioAlbumStorage, AudioArtistStorage,
-               AudioGenreStorage, ImageStorage,
+    devices = [AudioStorage,
+               AudioAlbumStorage,
+               AudioArtistStorage,
+               AudioGenreStorage,
+               ImageStorage,
 
                HistoryDevice,
                GenericBookmarkDevice]
