@@ -4,9 +4,18 @@ from utils import logging
 from theme import theme
 
 
+_TYPE_MAP = {
+    Device.TYPE_SYSTEM:  "/",
+    Device.TYPE_GENERIC: "/storage",
+    Device.TYPE_AUDIO:   "/audio",
+    Device.TYPE_VIDEO:   "/video",
+    Device.TYPE_IMAGE:   "/image"
+}
+
+
 class RootDevice(Device):
     """
-    Device for uniting all devices in one directory list.
+    Storage device for uniting all devices in one directory list.
     """
 
     CATEGORY = Device.CATEGORY_INDEX
@@ -23,6 +32,7 @@ class RootDevice(Device):
         
         # table: type -> list of devices
         self.__device_lists = {
+            Device.TYPE_SYSTEM:  [],
             Device.TYPE_GENERIC: [],
             Device.TYPE_AUDIO:   [],
             Device.TYPE_VIDEO:   [],
@@ -40,23 +50,13 @@ class RootDevice(Device):
         
     def get_name(self):
     
-        return "MediaBox"
+        return "Shelf"
         
         
     def get_icon(self):
     
-        return theme.mb_device_n800
-        
-        
-    def get_root(self):
-    
-        f = File(self)
-        f.name = self.get_name()
-        f.path = "/"
-        f.mimetype = f.DEVICE_ROOT
-        f.folder_flags = f.ITEMS_COMPACT
-        return f
-
+        return None
+          
 
     def __device_comparator(self, a, b):
 
@@ -64,7 +64,6 @@ class RootDevice(Device):
                     (b.TYPE, b.CATEGORY, b.get_name()))
 
 
-
     def __list_devices(self, dtype):
     
         devs = self.__device_lists[dtype]
@@ -78,9 +77,10 @@ class RootDevice(Device):
     
         out = []
         for name, info, path, icon in [
-            ("Music", "Browse Music Library", "/audio", theme.mb_device_audio),
-            ("Videos", "Browse Video Library", "/video", theme.mb_device_video),
-            ("Pictures", "Browse Picture Library", "/image", theme.mb_device_image)
+            ("Music", "Browse Music Library", "/audio", theme.mb_folder_audio),
+            ("Videos", "Browse Video Library", "/video", theme.mb_folder_video),
+            ("Pictures", "Browse Picture Library", "/image", theme.mb_folder_image),
+            ("Storage & Network", "Browse storage and network", "/storage", theme.mb_folder_storage),
         ]:
             f = File(self)
             f.name = name
@@ -101,19 +101,37 @@ class RootDevice(Device):
         self.__favorites = self.call_service(msgs.BOOKMARK_SVC_LIST, [])
         self.__favorites.sort(lambda a,b:cmp((a.device_id, a.name),
                                              (b.device_id, b.name)))
-        
         return self.__favorites
 
 
+    def get_file(self, path):
+
+        f = None    
+        if (path == "/"):
+            f = File(self)
+            f.name = self.get_name()
+            f.path = "/"
+            f.mimetype = f.DEVICE_ROOT
+            f.folder_flags = f.ITEMS_COMPACT
+        
+        else:
+            for c in self.__list_categories():
+                if (c.path == path):
+                    f = c
+                    break
+            #end fir
+        #end if
+
+        return f
+        
 
     def get_contents(self, path, begin_at, end_at, cb, *args):
-    
-    
+
         items = []
     
         if (path.path == "/"):
-            items += self.__list_devices(Device.TYPE_GENERIC)
             items += self.__list_categories()
+            items += self.__list_devices(Device.TYPE_SYSTEM)
             items += self.__list_favorites()
 
         elif (path.path == "/audio"):
@@ -125,6 +143,9 @@ class RootDevice(Device):
         elif (path.path == "/image"):
             items += self.__list_devices(Device.TYPE_IMAGE)
 
+        elif (path.path == "/storage"):
+            items += self.__list_devices(Device.TYPE_GENERIC)
+
         
         cnt = 0
         for f in items:
@@ -136,9 +157,14 @@ class RootDevice(Device):
         cb(None, *args)       
 
 
-    def __on_remove_from_dashboard(self, folder, f):
+    def __on_add_to_playlist(self, folder, f):
     
-        logging.debug("removing from dashboard: %s", f.name)
+        self.emit_message(msgs.PLAYLIST_ACT_APPEND, "", f)
+
+
+    def __on_remove_from_shelf(self, folder, f):
+    
+        logging.debug("removing from shelf: %s", f.name)
         f.bookmarked = False
         self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, self.get_root())
 
@@ -147,8 +173,11 @@ class RootDevice(Device):
     
         options = []
         if (f in self.__favorites):
-            options.append((None, "Remove from Dashboard",
-                            self.__on_remove_from_dashboard))
+            if (not f.full_path.startswith("playlist://")):
+                options.append((None, "Add to Playlist",
+                                self.__on_add_to_playlist))
+            options.append((None, "Remove from Shelf",
+                            self.__on_remove_from_shelf))
 
         return options
 
@@ -161,7 +190,8 @@ class RootDevice(Device):
             if (device.TYPE in self.__device_lists):
                 self.__device_lists[device.TYPE].append(device)
             
-            self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, self.get_root())
+            folder = self.get_file(_TYPE_MAP[device.TYPE])
+            self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, folder)
         #end if
 
 
@@ -174,6 +204,6 @@ class RootDevice(Device):
             if (device.TYPE in self.__device_lists):
                 self.__device_lists[device.TYPE].remove(device)
 
-            self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, self.get_root())
-
+            folder = self.get_file(_TYPE_MAP[device.TYPE])
+            self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, folder)
         #end if
