@@ -3,6 +3,9 @@ from theme import theme
 
 
 class VideoThumbnailer(Thumbnailer):
+    """
+    Thumbnailer for creating video thumbnails.
+    """
 
     def __init__(self):
     
@@ -16,5 +19,5 @@ class VideoThumbnailer(Thumbnailer):
 
     def make_quick_thumbnail(self, f):
     
-        return (theme.mb_frame_video.get_path(), True)
+        return (theme.mb_file_video.get_path(), True)
 
