@@ -39,10 +39,7 @@ class StorageBrowser(ThumbableGridView):
 
         # timestamp of the last list rendering
         self.__last_list_render_time = 0
-
-        # range of subfolder, if any
-        self.__subfolder_range = None
-        
+       
         # callback for loading thumbnails
         self.__thumbnailer = lambda *f:None
         
@@ -65,8 +62,10 @@ class StorageBrowser(ThumbableGridView):
     
         ThumbableGridView.__init__(self)
         self.add_overlay_renderer(self.__render_message)
-        self.add_overlay_renderer(self.__render_search_box)
-        self.add_overlay_renderer(self.__render_caps)
+        #self.add_overlay_renderer(self.__render_search_box)
+        #self.add_overlay_renderer(self.__render_caps)
+
+        self.connect_item_shifted(self.__on_shift_item)
 
 
     def connect_folder_begin(self, cb, *args):
@@ -126,16 +125,16 @@ class StorageBrowser(ThumbableGridView):
         x, y = self.get_screen_pos()
         w, h = self.get_size()
        
-        tw, th = text_extents(self.__message, theme.font_mb_listitem)
+        tw, th = text_extents(self.__message, theme.font_list_message)
         bw = tw + 20
         bh = th + 6
         tx = (w - bw) / 2 + (bw - tw) / 2
         ty = (h - bh) + (bh - th) / 2
 
         screen.fill_area((w - bw) / 2, h - bh,
-                         bw, bh, theme.color_mb_list_letter_background)
-        screen.draw_text(self.__message, theme.font_mb_listitem, tx, ty,
-                         theme.color_mb_list_letter)
+                         bw, bh, theme.color_list_message_background)
+        screen.draw_text(self.__message, theme.font_list_message, tx, ty,
+                         theme.color_list_message)
 
 
     def __render_search_box(self, screen):
@@ -173,13 +172,13 @@ class StorageBrowser(ThumbableGridView):
 
     def __on_item_clicked(self, item):
     
-        idx = self.get_items().index(item)
+        #idx = self.get_items().index(item)
     
-        self.set_cursor(idx)
-        self.set_hilight(idx)
+        #self.set_cursor(idx)
+        #self.set_hilight(idx)
         #self.invalidate_item(idx)
-        self.invalidate()
-        self.render()
+        #self.invalidate()
+        #self.render()
 
         f = item.get_file()
         
@@ -214,122 +213,6 @@ class StorageBrowser(ThumbableGridView):
         if (choice != -1):
             callbacks[choice](cwd, f)
             
-        """
-        idx = self.get_items().index(item)
-    
-        options = []
-
-        if (not f.bookmarked):
-            options.append((None, "Put on Dashboard",
-                            self.EVENT_FILE_BOOKMARKED))
-    
-        if (cwd.folder_flags & cwd.ITEMS_ENQUEUEABLE):
-            options.append((None, "Add to a Playlist",
-                            self.EVENT_FILE_ENQUEUED))
-
-        if (f.folder_flags & f.INDEXABLE):
-            options.append((None, "Add to Media Library",
-                            self.EVENT_FILE_ADDED_TO_LIBRARY))
-
-        if (cwd.folder_flags & cwd.ITEMS_DELETABLE):
-            options.append((None, "Delete",
-                            self.EVENT_FILE_REMOVED))
-
-        if (not options):
-            return
-            
-        dlg = OptionDialog("Options")
-        for icon, label, ev in options:
-            dlg.add_option(icon, label)
-            
-        if (dlg.run() != 0):
-            return
-
-        choice = dlg.get_choice()
-        if (choice != -1):
-            ev = options[choice][2]
-
-            if (ev == self.EVENT_FILE_ENQUEUED):
-                pass
-            
-            elif (ev == self.EVENT_FILE_REMOVED):
-                self.__remove_item(idx)
-            
-            self.emit_event(ev, f)
-        #end if
-        """
-
-
-    """
-    def __on_item_button_pressed(self, button, item):
-    
-        idx = self.get_items().index(item)
-
-        print "BUTTON", button, idx
-        if (button == item.BUTTON_PLAY):
-            f = item.get_file()
-            self.set_hilight(idx)
-            self.render()
-            if (f.mimetype.endswith("-folder")):
-                self.load_folder(f, self.GO_CHILD)
-            else:
-                self.send_event(self.EVENT_FILE_OPENED, f)
-
-        elif (button == item.BUTTON_OPEN):
-            print "OPEN"
-            f = item.get_file()
-            self.insert_folder(f)
-
-
-        
-    def __on_item_button(self, item, idx, button):
-
-        if (idx == -1): return
-        
-        if (button == item.BUTTON_PLAY):
-            f = item.get_file()
-            self.set_hilight(idx)
-            self.render()
-            if (f.mimetype.endswith("-folder")):
-                self.load_folder(f, self.GO_CHILD)
-            else:
-                self.send_event(self.EVENT_FILE_OPENED, f)
-
-        elif (button == item.BUTTON_OPEN):
-            f = item.get_file()
-            self.insert_folder(f)
-
-        elif (button == item.BUTTON_ENQUEUE):
-            if (idx == 0):
-                f = self.get_current_folder()
-            else:
-                f = item.get_file()
-            self.send_event(self.EVENT_FILE_ENQUEUED, f)
-
-        elif (button == item.BUTTON_REMOVE):
-            self.__remove_item(idx - 1)
-
-        elif (button == item.BUTTON_REMOVE_PRECEDING):
-            a = 0
-            b = idx - 1
-            self.begin_bulk_operation()
-            print a, b, len(range(a, b + 1))
-            for i in range(a, b + 1):
-                self.__remove_item(0)
-            self.end_bulk_operation()
-
-        elif (button == item.BUTTON_REMOVE_SUCCEEDING):
-            a = idx - 1
-            b = len(self.get_items()) - 1 - 1
-            self.begin_bulk_operation()
-            for i in range(a, b + 1):
-                self.__remove_item(a)
-            self.end_bulk_operation()
-
-        elif (button == item.BUTTON_ADD_TO_LIBRARY):
-            f = self.get_current_folder()
-            self.send_event(self.EVENT_FILE_ADDED_TO_LIBRARY, f)
-    """
 
     def __remove_item(self, idx):
 
@@ -337,14 +220,10 @@ class StorageBrowser(ThumbableGridView):
         folder.delete_file(idx)
 
 
-    """
-    def __on_swap_items(self, idx1, idx2):
+    def __on_shift_item(self, pos, amount):
     
         folder = self.get_current_folder()
-        if (folder):
-            # -1 because there's a header item
-            folder.swap(idx1 - 1, idx2 - 1)
-    """
+        folder.shift_file(pos, amount)
 
         
     def set_root_device(self, device):
@@ -405,8 +284,6 @@ class StorageBrowser(ThumbableGridView):
                 found = True
         #end for
         
-        #if (self.__path_stack and self.__path_stack[-1][1] == _STATUS_INVALID):
-        #    self.reload_current_folder()
         if (found and not self.__is_bulk_operation):
             self.reload_current_folder()
     
@@ -560,10 +437,7 @@ class StorageBrowser(ThumbableGridView):
 
         
     def go_parent(self):
-    
-        #if (self.__subfolder_range):
-        #    self.__close_subfolder()
-        
+       
         if (len(self.__path_stack) > 1):
             self.__path_stack.pop()
             path, status = self.__path_stack.pop()
@@ -578,7 +452,8 @@ class StorageBrowser(ThumbableGridView):
         Reloads the current folder.
         """
         
-        self.load_folder(self.get_current_folder(), self.GO_NEW)  
+        if (self.get_current_folder()):
+            self.load_folder(self.get_current_folder(), self.GO_PARENT)
         
         
     def load_folder(self, folder, direction, force_reload = False):
@@ -590,7 +465,6 @@ class StorageBrowser(ThumbableGridView):
         @param force_reload: whether to force reloading the folder
         """
 
-        self.emit_event(self.EVENT_FOLDER_BEGIN, folder)
 
         # are we just reloading the same folder?
         reload_only = False
@@ -620,6 +494,8 @@ class StorageBrowser(ThumbableGridView):
             self.__path_stack.append([folder, _STATUS_INCOMPLETE])
 
         self.switch_item_set(folder.full_path)
+        self.set_cursor(-1)
+        self.emit_event(self.EVENT_FOLDER_BEGIN, folder)
         
         if (full_reload):
             # reload list
@@ -634,20 +510,10 @@ class StorageBrowser(ThumbableGridView):
             #    buttons.append((header.BUTTON_ADD_TO_LIBRARY, theme.mb_item_btn_add))
             #header.set_buttons(*buttons)
             
-            if (folder.folder_flags & folder.ITEMS_SORTABLE):
-                self.set_drag_sort_enabled(True)
-            else:
-                self.set_drag_sort_enabled(False)
-
         else:
             # don't reload list
             pass
 
-        if (folder.folder_flags & folder.ITEMS_COMPACT):
-            self.set_items_per_row(3)
-        else:
-            self.set_items_per_row(1)
-
         # animate
         if (direction == self.GO_CHILD):
             self.fx_slide_left()
@@ -666,7 +532,7 @@ class StorageBrowser(ThumbableGridView):
             self.emit_event(self.EVENT_FOLDER_COMPLETE, folder)
 
         # now is a good time to collect garbage
-        import gc; gc.collect()    
+        #import gc; gc.collect()    
       
         
     def complete_current_folder(self):
@@ -701,7 +567,10 @@ class StorageBrowser(ThumbableGridView):
             else:
                 #self.get_item(0).set_info("%d items" % len(self.get_files()))
                 #self.invalidate_item(0)
-                self.set_message("")
+                if (len(self.get_files()) > 0):
+                    self.set_message("")
+                else:
+                    self.set_message("Folder contains no media")
                 
                 # mark folder as complete
                 self.__path_stack[-1][1] = _STATUS_OK
@@ -716,8 +585,12 @@ class StorageBrowser(ThumbableGridView):
                 #self.send_event(self.EVENT_FOLDER_OPENED,
                 #                self.get_current_folder())
 
+                # now is a good time to collect garbage
+                import gc; gc.collect()    
+
+
             now = time.time()
-            if (not f or now > self.__last_list_render_time + 1.0):
+            if (not f or len(self.get_files()) % 10 == 0): #now > self.__last_list_render_time + 1.0):
                 self.__last_list_render_time = now
                 #self.invalidate_buffer()
                 self.render()
@@ -731,8 +604,8 @@ class StorageBrowser(ThumbableGridView):
 
         cwd = self.get_current_folder()
         num_of_items = len(self.get_files())
-        cwd.get_contents(num_of_items, 0, on_child, self.__token, cwd, [])
         self.__token = (self.__token + 1) % 100
+        cwd.get_contents(num_of_items, 0, on_child, self.__token, cwd, [])
         
         
     def __add_file(self, f):
@@ -754,9 +627,7 @@ class StorageBrowser(ThumbableGridView):
             item.set_compact(True)        
 
         if (cwd.folder_flags & cwd.ITEMS_SORTABLE):
-            item.set_grip_visible(True)
-        else:
-            item.set_grip_visible(False)
+            item.set_draggable(True)
     
         self.append_item(item)
 
