@@ -15,15 +15,19 @@ MEDIA_VIDEO = 1
 MEDIA_AUDIO = 2
 MEDIA_IMAGE = 4
 
+ORIENTATION_LANDSCAPE = "landscape"
+ORIENTATION_PORTRAIT = "portrait"
+
 
 _cfg = Config("",
               [("current_device", Config.STRING, ""),
                ("current_viewer", Config.STRING, ""),
                ("mediaroot", Config.STRING_LIST,
-                             ["/home/user/MyDocs/.videos",
-                              "/home/user/MyDocs/.sounds",
-                              "/home/user/MyDocs/.images"]),
+                             ["/home/user/MyDocs",
+                              "/media"]),
                ("mediaroot_types", Config.INTEGER_LIST, []),
+               ("orientation", Config.STRING, ORIENTATION_LANDSCAPE),
+               ("portrait_swap_volume", Config.BOOL, True),
                ("repeat_mode", Config.STRING, REPEAT_MODE_NONE),
                ("shuffle_mode", Config.STRING, SHUFFLE_MODE_NONE),
                ("scan_at_startup", Config.BOOL, True),
@@ -87,6 +91,25 @@ def set_mediaroot(l):
     _cfg["mediaroot_types"] = mtypes
 
 
+def orientation():
+
+    return _cfg["orientation"]
+    
+    
+def set_orientation(o):
+
+    _cfg["orientation"] = o
+
+
+def portrait_swap_volume():
+
+    return _cfg["portrait_swap_volume"]
+    
+    
+def set_portrait_swap_volume(v):
+
+    _cfg["portrait_swap_volume"] = v
+    
 
 def repeat_mode():
 
