@@ -3,7 +3,7 @@ This package contains the media player backends.
 """
 
 from DummyBackend import DummyBackend
-from utils import maemo
+import platforms
 from mediabox import values
 from utils import mimetypes
 from utils import logging
@@ -13,15 +13,15 @@ import os
 
 _DUMMY = DummyBackend()
 
-if (maemo.IS_MER):
+if (platforms.PLATFORM == platforms.MER):
     from XineBackend import XineBackend
     _XINE = XineBackend()
     _PLAYERS = {"gst": _GST,
                 "mplayer": _MPLAYER,
                 "xine": _XINE}
     _SUFFIX = ".mer"
-    
-elif (maemo.IS_MAEMO):
+
+elif (platforms.PLATFORM == platforms.MAEMO4):
     from GstBackend import GstBackend
     from MPlayerBackend import MPlayerBackend
     from OSSOBackend import OSSOBackend
@@ -32,6 +32,13 @@ elif (maemo.IS_MAEMO):
                 "mplayer": _MPLAYER,
                 "oms": _OMS}
     _SUFFIX = ".maemo"
+
+elif (platforms.PLATFORM == platforms.MAEMO5):
+    from GstBackend import GstBackend
+    _GST = GstBackend()
+    _PLAYERS = {"gst": _GST}
+    _SUFFIX = ".maemo5"
+
                 
 else:
     from GstBackend import GstBackend
@@ -113,6 +120,13 @@ def get_player_for_mimetype(mimetype):
     DUMMY player if no appropriate player was found.
     """
 
+    # this operation is not time-critical, so we may read in the mapping table
+    # every time
+    _read_mapping_table(_PLAYERS_MAPPING_FILE1)
+    if (os.path.exists(_PLAYERS_MAPPING_FILE2)):
+        _read_mapping_table(_PLAYERS_MAPPING_FILE2)
+    
+
     mediatype = mimetypes.mimetype_to_name(mimetype)
     
     backend = get_backend_for(mediatype)
