@@ -2,7 +2,7 @@
 Base class of all storage devices.
 """
 
-from com import Component
+from com import Component, msgs
 from utils import logging
 
 
@@ -18,13 +18,14 @@ class Device(Component):
      - L{CATEGORY_LAN} - file system for accessing stuff on the LAN, e.g. UPnP devices
      - L{CATEGORY_WAN} - file system for accessing stuff on the internet
      - L{CATEGORY_OTHER} - file system for accessing other stuff, e.g. mobile phones
+     - L{CATEGORY_HIDDEN} - hidden device not directly visible in the browser
 
     The category determines the position where the device will appear in the
     user interface. The list of devices is sorted first by category, then
     alphabetically.
     
     Storage devices are of type
-     - L{TYPE_PRIVATE}
+     - L{TYPE_SYSTEM}
      - L{TYPE_GENERIC}
      - L{TYPE_AUDIO}
      - L{TYPE_VIDEO}
@@ -32,8 +33,7 @@ class Device(Component):
      
     Viewers list devices of certain types. The video viewer e.g. only lists
     devices of type L{TYPE_VIDEO}, while the devices of type L{TYPE_GENERIC}
-    are listed by the folder viewer. Devices of L{TYPE_PRIVATE} are not listed
-    automatically.
+    are listed by the folder viewer.
 
     Every instance of a device has a unique device ID string that is returned by
     L{get_device_id}. This is ID is used by MediaBox to keep track of devices
@@ -53,8 +53,9 @@ class Device(Component):
     CATEGORY_LAN = 3
     CATEGORY_WAN = 4
     CATEGORY_OTHER = 5
+    CATEGORY_HIDDEN = 6
     
-    TYPE_PRIVATE = 0
+    TYPE_SYSTEM = 0
     TYPE_GENERIC = 1
     TYPE_AUDIO = 2
     TYPE_VIDEO = 3
@@ -69,6 +70,8 @@ class Device(Component):
 
     def __init__(self):
     
+        self.__bookmarks = []
+
         Component.__init__(self)
         
         
@@ -132,13 +135,15 @@ class Device(Component):
     def get_root(self):
         """
         Returns the File object representing the root path of the device.
-        The returned path does not contain the device prefix.
         @since: 0.96
         
         @return: root file object
         """
     
-        raise NotImplementedError
+        try:
+            return self.get_file("/")
+        except:
+            import traceback; traceback.print_exc()
         
         
     def get_file(self, path):
@@ -165,33 +170,18 @@ class Device(Component):
         raise NotImplementedError
 
 
-    def delete_file(self, folder, idx):
+    def delete_file(self, folder, f):
         """
         Deletes the file given by its index number from the given folder.
-        @since: 0.96.5
+        @since: 2009.10.7
         
         @param folder: file object of the parent folder
-        @param idx:    index of file to delete
+        @param f:      file to delete
         """
         
-        # support legacy plugins
-        logging.warning("DEPRECATED: %s implements 'delete'",
-                        self.__class__.__name__)        
-        self.delete(folder._LEGACY_SUPPORT_file_to_delete)
-
-        
-    def delete(self, f):
-        """
-        Can be implemented by devices to support deleting files.
-        @since: 096
-        @deprecated: use L{delete_file} instead
-        
-        @param f: file object to delete
-        """
-    
         raise NotImplementedError
 
-
+        
     def keep(self, f):
         """
         Keeps the given file. Storage device can implement this method to
@@ -204,17 +194,46 @@ class Device(Component):
         raise NotImplementedError
 
 
-    def swap(self, f, idx1, idx2):
+    def shift_file(self, f, pos, amount):
         """
-        Swaps two files in this folder.
-        @since: 0.96.5
+        Shifts the file at the given position by the given amount.
+        The shifting amount may be positive or negative.
+        @since: 2009.10.20
         
-        @param idx1: index of first file
-        @param idx2: index of second file
+        @param folder: file object representing the folder
+        @param pos: index of file
+        @param amount: shifting amount
         """
         
         pass
 
+    
+    def __on_add_to_playlist(self, folder, f):
+    
+        self.emit_message(msgs.PLAYLIST_ACT_APPEND, "", f)
+
+
+    def __on_put_on_shelf(self, folder, f):
+        
+        f.bookmarked = True
+
+
+    def get_file_actions(self, folder, f):
+        """
+        Returns a list of actions for the given file.
+        @since: 2009.10
+        
+        @param folder: file object representing the folder
+        @param f: file object
+        @return: list of (icon, action_name, callback) tuples
+        """
+    
+        actions = []
+        actions.append((None, "Add to Playlist", self.__on_add_to_playlist))
+        if (not f.bookmarked):
+            actions.append((None, "Put on Shelf", self.__on_put_on_shelf))
+        
+        return actions
 
 
     def ls(self, path):
@@ -332,3 +351,23 @@ class Device(Component):
         
         return f.resource
 
+
+    def get_bookmarked(self, f):
+
+        if (not self.__bookmarks):
+            self.__bookmarks = self.call_service(msgs.BOOKMARK_SVC_LIST, [])
+
+        return (f in self.__bookmarks)
+
+
+    def set_bookmarked(self, f, v):
+
+        if (v):
+            self.emit_message(msgs.BOOKMARK_SVC_ADD, f)
+        else:
+            self.emit_message(msgs.BOOKMARK_SVC_DELETE, f)
+
+
+    def handle_BOOKMARK_EV_INVALIDATED(self):
+
+        self.__bookmarks = self.call_service(msgs.BOOKMARK_SVC_LIST, [])
