@@ -14,10 +14,19 @@ class Button(ImageButton):
         self.set_size(w + 24, h + 24)
 
 
+    def set_text(self, text):
+        """
+        @since: 0.96.5
+        """
+    
+        self.__label = text
+        self.render()
+
+
     def _render_content(self, cnv):
 
         w, h = self.get_size()
 
         cnv.draw_centered_text(self.__label, theme.font_mb_plain,
-                               0, 0, w, h, "#000000")
+                               0, 0, w, h, theme.color_mb_button_text)
 
