@@ -80,6 +80,11 @@ class GridView(ItemView):
         #end if
 
 
+    def get_items_per_row(self):
+    
+        return self.__items_per_row
+
+
 
     def set_background(self, color):
         """
@@ -96,6 +101,15 @@ class GridView(ItemView):
             self.invalidate()
 
 
+    def _reload(self):
+
+        self.__bg_color.reload()
+        self.set_background(self.__bg_color)
+        self.invalidate()
+        for item in self.get_items():
+            item._invalidate_cached_pixmap()
+
+
     def invalidate(self):
         """
         Invalidates this view. This causes the view to be redrawn completely
@@ -240,6 +254,9 @@ class GridView(ItemView):
             # render only if not floating
             if (idx != self.__floating_item):
                 item.render_at(self.__buffer, item_x, item_y)
+            else:
+                self.__buffer.fill_area(item_x, item_y, item_w, item_h,
+                                        "#66666620")
         #end if
         
         
@@ -369,7 +386,7 @@ class GridView(ItemView):
         #end if
         
         
-        
+    """
     def set_cursor(self, pos):
     
         prev_pos = self.get_cursor()
@@ -379,7 +396,7 @@ class GridView(ItemView):
         self.__render_item(pos)
         self.scroll_to_item(pos)
         self.render()
-        
+    """
         
     def float_item(self, pos, x = 0, y = 0):
         """
